@@ -732,7 +732,7 @@ check_pos_rec (int x, int y, int rx, int ry, int rtx, int rty)
 }
 
 int
-partial_delete (int x, int y, int tx, int ty)
+partial_delete ()
 /* deletes the bonds and labels inside the selection rectangle */
 {
   int d, r = False;
@@ -1250,7 +1250,7 @@ move_pos (int x, int y, int tx, int ty)
 }
 
 int
-partial_move (int x, int y, int tx, int ty, int dx, int dy)
+partial_move (int dx, int dy)
 /* updates the position of all selected bonds and labels */
 {
   struct data *hp_bond;
@@ -1643,7 +1643,7 @@ linked to something outside the box, are ignored. **/
 }
 
 int
-partial_rescale (int x, int y, int tx, int ty, int updown, int aniso)
+partial_rescale (int updown, int aniso)
 /* updates the position of all selected bonds and labels */
 {
   struct data *hp_bond;
