@@ -130,13 +130,13 @@ extern struct xy_co *calc_angle(int x, int y, int ang_type, int angle, int);
 extern struct xy_co *position(int x, int y, int ax, int ay, int ang_type);
 extern void setup_data(void);
 extern void clear_data(void);
-extern int partial_delete(int x, int y, int tx, int ty);
+extern int partial_delete(void);
 extern void center_mol(void);
 extern int move_pos(int x, int y, int tx, int ty);
 extern int check_pos_rec(int x, int y, int rx, int ry, int rtx, int rty);
-extern int partial_move(int x, int y, int tx, int ty, int dx, int dy);
-extern int partial_rotate(/*int xcent, int ycent,*/ double rotsin, double rotcos);
-extern int partial_rescale(int x, int y, int tx, int ty, int updown, int aniso);
+extern int partial_move(int dx, int dy);
+extern int partial_rotate(double rotsin, double rotcos);
+extern int partial_rescale(int updown, int aniso);
 
 extern int calc_vector(int dx, int dy);
 extern struct xy_co *multi_bonds(int mx, int my, int mtx, int mty, int r);
@@ -181,8 +181,8 @@ extern void Set_Line(int);
 /*	draw.c	*/
 
 extern void Add_double( int, int);
-extern void Add_vector(int, int, int);
-extern void Add_ring(int, int, int, int, int);
+extern void Add_vector(int);
+extern void Add_ring(int, int, int);
 extern void Del_vector( int, int);
 extern void Set_vector( int, int,int);
 extern void Put_vector( int, int);
@@ -194,7 +194,7 @@ extern void Del_atom( int, int);
 extern void Set_start_rec( int, int);
 extern void Put_rec( int, int);
 extern void Del_rec(void);
-extern void Mark_rec( int, int, int);
+extern void Mark_rec(int);
 extern void Mark_atom( int, int);
 extern void Center(void);
 extern void Put_pmove( int, int,int);
