@@ -109,7 +109,7 @@ Set_vector (int event_x, int event_y, int curbond)
 }
 
 void
-Add_vector (int event_x, int event_y, int cbond)
+Add_vector (int cbond)
 /* adds a bond vector from the previous to the current cursor position */
 {
   if ((hp->x - hp->tx) || (hp->y - hp->ty))
@@ -121,7 +121,7 @@ Add_vector (int event_x, int event_y, int cbond)
 }
 
 void
-Add_ring (int event_x, int event_y, int draw_angle, int curbond, int ringtype)
+Add_ring (int draw_angle, int curbond, int ringtype)
 /* adds a polygon clockwise around the previous and current position */
 {
   double length;		/* length of the drawn bond */
@@ -553,18 +553,22 @@ Del_rec ()
   if (!mark.flag)
     return;			/* if nothing marked, nothing to do */
 
+  modify = partial_delete();
+
+/*  
   modify =
     partial_delete (round_coord (hp->x, size_factor),
-		    round_coord (hp->y, size_factor), round_coord (hp->tx,
-								   size_factor),
+		    round_coord (hp->y, size_factor), 
+		    round_coord (hp->tx, size_factor),
 		    round_coord (hp->ty, size_factor));
+*/
   if (modify == True)
     mark.flag = False;
 
 }
 
 void
-Mark_rec (int event_x, int event_y, int control_pressed)
+Mark_rec (int control_pressed)
 /* mark all bonds and labels inside the rectangular selection area */
 {
   struct data *hp_bond;
@@ -888,8 +892,7 @@ Put_pmove (int event_x, int event_y, int axis)
       dy = y - hp->y;
 	if (axis == 1) dy = 0;
 	if (axis == 2) dx = 0;
-      if (partial_move (mark.x, mark.y, mark.w + mark.x,
-			mark.y + mark.h, dx, dy))
+      if (partial_move (dx, dy))
 	modify = True;
       mark.x = mark.x + dx;
       mark.y = mark.y + dy;
@@ -1077,8 +1080,7 @@ Put_pscale (int event_x, int event_y, int aniso)
   if (mark.flag)
     {
       dx = x - hp->x;
-      if (partial_rescale (mark.x, mark.y, mark.w + mark.x,
-			   mark.y + mark.h, dx, aniso))
+      if (partial_rescale (dx, aniso))
 	modify = True;
       Display_Mol ();
     }
