@@ -168,7 +168,7 @@ Display_Mol ()
 		 siz=hpc_c->size;  // font size
                  if (y-ty==0&& hpc_c->direct ==0) { // horizontal bond, left justified label
                       strl=0;
-                      for (i=0;i<strlen(hpc_c->c);i++) { // count regular characters in label
+                      for (i=0;i<(int)strlen(hpc_c->c);i++) { // count regular characters in label
                         if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
                         && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
                         strl++;
@@ -195,7 +195,7 @@ Display_Mol ()
 		 siz=hpc_c->size;
                  if (y-ty==0 ){
                       strl=0;
-                      for (i=0;i<strlen(hpc_c->c);i++) {
+                      for (i=0;i<(int)strlen(hpc_c->c);i++) {
                         if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
                         && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
                         strl++;
@@ -276,8 +276,7 @@ Display_Mol ()
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	  break;
 	case 13:
-	  DrawAcross (x, y, tx, ty,
-		      hpc->smarked + hpc->tmarked,hpc->color);
+/* "crossing" bonds are drawn in their own loop later, to make sure they end up on top */
 	  break;
 	case 4:
 	  {			/*middouble */
@@ -374,6 +373,85 @@ Display_Mol ()
 	}
     }
 
+/* second loop - only for drawing "crossing" bonds (type 13) */
+  hpc = da_root.next;
+  for (d = 0; d < hp->n; d++)
+    {
+    int x=hpc->x;
+    int y=hpc->y;
+    int tx=hpc->tx;
+    int ty=hpc->ty;
+#if 1
+//constant clipping factor works better than original 4*size_factor
+	if ( !use_whiteout) {
+	        int siz,strl;
+	        int j;
+		i=has_label(hpc->x,hpc->y);
+		if (i>=0) {
+                 hpc_c = dac_root.next;
+                 for (j = 0; j < i; j++)hpc_c=hpc_c->next;
+		 siz=hpc_c->size;  // font size
+                 if (y-ty==0&& hpc_c->direct ==0) { // horizontal bond, left justified label
+                      strl=0;
+                      for (i=0;i<(int)strlen(hpc_c->c);i++) { // count regular characters in label
+                        if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
+                        && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
+                        strl++;
+                      }
+                   if (tx>x) {
+                      x+=(strl-1)*3.2*(siz+1); // move bond endpoint off label
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='H') x+=5;
+                      if (hpc_c->c[strlen(hpc_c->c)-2]=='_')
+                        x-=1.6*(siz+1);        // adjust for trailing subscripts
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='}')
+                        x-=4.8*(siz+1);
+                   }     
+                   else {
+                      }
+		 }
+		int ox=x;
+				x += (3.2*(siz+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				y += (3.2*(siz+1)/calc_vector(abs(tx-ox),abs(ty-y))) *(ty-y);
+				}
+		i=has_label(hpc->tx,hpc->ty);
+		if (i>=0) {
+                 hpc_c = dac_root.next;
+                 for (j = 0; j < i; j++)hpc_c=hpc_c->next;
+		 siz=hpc_c->size;
+                 if (y-ty==0 ){
+                      strl=0;
+                      for (i=0;i<(int)strlen(hpc_c->c);i++) {
+                        if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
+                        && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
+                        strl++;
+                      }
+                   if ( hpc_c->direct<-1) {
+                      if (tx>x)
+                        tx-=(strlen(hpc_c->c)-1)*3.2*(siz+1);
+//QUAK                      else
+//QUAK                       tx+=(strlen(hpc_c->c)-1)*3.2*(siz+1);
+                   }
+                   else if ( hpc_c->direct==0 && tx<x) {
+                        tx+=(strl-1)*3.2*(siz+1);
+                      if (hpc_c->c[strlen(hpc_c->c)-2]=='_')
+                        tx-=1.6*(siz+1);
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='}')
+                        tx-=4.8*(siz+1);
+                    }    
+                }  
+		int otx=tx;
+				tx -= (3.2*(siz+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				ty -= (3.2*(siz+1)/calc_vector(abs(otx-x),abs(ty-y))) *(ty-y);
+				}
+		}		
+#endif
+	if (hpc->bond==13)
+	  DrawAcross (x, y, tx, ty,
+		      hpc->smarked + hpc->tmarked,hpc->color);
+      hpc = hpc->next;
+    }
+
+/* */
   hpc_c = dac_root.next;
   for (d = 0; d < hp->nc; d++)
     {
@@ -529,15 +607,15 @@ DrawAcross (int x, int y, int tx, int ty, int active,int color)
   thegc = background_gc;
 
   coord = center_double_bond (x, y, tx, ty, 6);
-  mypoints[0].x = (coord->x + (coord->tx - coord->x) / 4) * size_factor;
-  mypoints[0].y = (coord->y + (coord->ty - coord->y) / 4) * size_factor;
-  mypoints[1].x = (coord->tx - (coord->tx - coord->x) / 4) * size_factor;
-  mypoints[1].y = (coord->ty - (coord->ty - coord->y) / 4) * size_factor;
+  mypoints[0].x = (coord->x + (coord->tx - coord->x) / 8) * size_factor;
+  mypoints[0].y = (coord->y + (coord->ty - coord->y) / 8) * size_factor;
+  mypoints[1].x = (coord->tx - (coord->tx - coord->x) / 8) * size_factor;
+  mypoints[1].y = (coord->ty - (coord->ty - coord->y) / 8) * size_factor;
   coord++;
-  mypoints[2].x = (coord->tx - (coord->tx - coord->x) / 4) * size_factor;
-  mypoints[2].y = (coord->ty - (coord->ty - coord->y) / 4) * size_factor;
-  mypoints[3].x = (coord->x + (coord->tx - coord->x) / 4) * size_factor;
-  mypoints[3].y = (coord->y + (coord->ty - coord->y) / 4) * size_factor;
+  mypoints[2].x = (coord->tx - (coord->tx - coord->x) / 8) * size_factor;
+  mypoints[2].y = (coord->ty - (coord->ty - coord->y) / 8) * size_factor;
+  mypoints[3].x = (coord->x + (coord->tx - coord->x) / 8) * size_factor;
+  mypoints[3].y = (coord->y + (coord->ty - coord->y) / 8) * size_factor;
   gdk_draw_polygon (picture, thegc, TRUE, (GdkPoint *) mypoints,
 		    (gint) npoints);
 
@@ -1100,6 +1178,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 #ifdef GTK2
   int dummy;
   gchar l[8];
+  gchar *c_p;
   gunichar hc, hl;
   gunichar text[MAXCL];
   gunichar symbol[MAXCL];
@@ -1143,6 +1222,7 @@ memset(l,0,8*sizeof(gchar));
   fprintf(stderr,"invalid character in chemtool file\n");
   return;
   }
+  c_p=c;
   if (!thelayout) thelayout = gtk_widget_create_pango_layout(drawing_area,"X");
   pango_layout_set_font_description(thelayout,font[fontsize]);
   pango_layout_get_pixel_size(thelayout, &tw, &a);  
@@ -1831,6 +1911,9 @@ g_unichar_to_utf8(text[d],l);
 	  save_x = sub_lastx = sup_lastx = x;
 	}
     }
+#ifdef GTK2
+        free(c_p);
+#endif
 }
 
 #ifdef GTK2
