@@ -2,7 +2,7 @@
 #define __GTKINTL_H__
 
 
-#ifndef DISABLE_NLS
+#ifdef ENABLE_NLS
 #include<libintl.h>
 #if !defined _
 #define _(String) dgettext("gtk+",String)
