@@ -1136,7 +1136,7 @@ undo_history_memory_usage (UNDO_HISTORY * history)
   size_t total;
 
   total = 0;
-  for (ix = 0; ix < history->length; ix++)
+  for (ix = 0; ix < (int)history->length; ix++)
     {
       total += history->item[ix].size;
     }
@@ -1215,7 +1215,7 @@ undo_history_shrink (UNDO_HISTORY * history, size_t size)
 
   total = 0;
   first_saved = 0;
-  for (ix = 0; ix < history->length; ix++)
+  for (ix = 0; ix < (int)history->length; ix++)
     {
       total += history->item[ix].size;
       while (total > size)
@@ -1281,7 +1281,7 @@ undo_strerror (int errcode)
   if (errcode < 0)
     return NULL;
 
-  if (errcode >= sizeof (err_string) / sizeof (char *))
+  if (errcode >= (int) (sizeof (err_string) / sizeof (char *)))
     return NULL;
 
   return err_string[errcode];
